@@ -5,5 +5,5 @@ use clap::Parser;
 #[clap(author, version, about, long_about = None)]
 pub struct Args {
     #[clap(subcommand)]
-    pub action: SubCommand,
+    pub command: SubCommand,
 }
